@@ -1,24 +1,25 @@
 from __future__ import annotations
+
+import re
 import shlex
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from enum import Enum
-from typing import Any, TypeVar, Callable, Type, ClassVar
+from typing import Any, Callable, ClassVar, Dict, Tuple, Type, TypeVar, TYPE_CHECKING
 
 T = TypeVar("T", bound="BaseStatus")
 
-if False:  # for mypy
+if TYPE_CHECKING:
     from .machine import Machine
 
 
-@dataclass
 class BaseStatus(ABC):
     @classmethod
     @property
     @abstractmethod
     def _comlist(
         cls: Type[T],
-    ) -> dict[str, tuple[bytes, Callable[[Any], Any]]]:  # pragma: no cover
+    ) -> Dict[str, Tuple[bytes, Callable[[Any], Any]]]:  # pragma: no cover
         ...
 
     @classmethod
@@ -28,23 +29,26 @@ class BaseStatus(ABC):
         ...
 
     @classmethod
-    def from_machine(cls: Type[T], connection: "Machine") -> T:
+    def from_machine(cls: Type[T], connection: "Machine") -> T:  # type: ignore
         out = connection.run_command_bytes(cls._com)
         return cls.from_bytes(out)
 
+    def __init__(self, **kwargs) -> None:  # pragma: no cover
+        ...
+
     @classmethod
     def from_bytes(cls: Type[T], out: bytes) -> T:
         return cls(
             **{
                 k: inst(v)
                 for (k, (_, inst)), v in zip(
-                    cls._comlist.items(), shlex.split(out.decode())
+                    cls._comlist.items(), shlex.split(out.decode())  # type: ignore
                 )
             }
         )
 
 
-def _get_protodef_or_def(var: str, default: Any):
+def _get_protodef_or_def(var: str, default: Any) -> bytes:
     return f"$[ top.getChild('PROTOcolDEFinition').variables.get('{var}'.lower(), {default}) ]".encode()
 
 
@@ -59,8 +63,11 @@ class RunStatus(BaseStatus):
     point: int
     state: str
 
-    _comlist: ClassVar[dict[str, tuple[bytes, Callable[[Any], Any]]]] = {
-        "name": (b"${RunTitle:--}", str),
+    _comlist: ClassVar[Dict[str, Tuple[bytes, Callable[[Any], Any]]]] = {
+        "name": (
+            b"${RunTitle:--}",
+            lambda out: re.sub(r"(<([\w.]+)>)?([^<]+)(</[\w.]+>)?", r"\3", out),
+        ),
         "stage": (b"${Stage:--1}", lambda x: int(x) if x != "PRERUN" else 0),
         "num_stages": (_get_protodef_or_def("${RunMacro}-Stages", -1), int),
         "cycle": (b"${Cycle:--1}", int),
@@ -81,55 +88,10 @@ class MachineStatus(BaseStatus):
     cover: str
     lamp_status: str
 
-    _comlist: ClassVar[dict[str, tuple[bytes, Callable[[Any], Any]]]] = {
+    _comlist: ClassVar[Dict[str, Tuple[bytes, Callable[[Any], Any]]]] = {
         "drawer": (b"$(DRAWER?)", str),
         "cover": (b'$[ "$(ENG?)" or "unknown" ]', str),
         "lamp_status": (b"$(LST?)", str),
     }
 
     _com: ClassVar[bytes] = b"RET " + b" ".join(v for v, _ in _comlist.values())
-
-
-_accesslevel_order: dict[str, int] = {
-    "Guest": 0,
-    "Observer": 1,
-    "Controller": 2,
-    "Administrator": 3,
-    "Full": 4,
-}
-
-
-class AccessLevel(Enum):
-    Guest = "Guest"
-    Observer = "Observer"
-    Controller = "Controller"
-    Administrator = "Administrator"
-    Full = "Full"
-
-    def __gt__(self, other: object) -> bool:
-        if not isinstance(other, AccessLevel):
-            other = AccessLevel(other)
-        return _accesslevel_order[self.value] > _accesslevel_order[other.value]
-
-    def __ge__(self, other: object) -> bool:
-        if not isinstance(other, AccessLevel):
-            other = AccessLevel(other)
-        return _accesslevel_order[self.value] >= _accesslevel_order[other.value]
-
-    def __lt__(self, other: object) -> bool:
-        if not isinstance(other, AccessLevel):
-            other = AccessLevel(other)
-        return _accesslevel_order[self.value] < _accesslevel_order[other.value]
-
-    def __le__(self, other: object) -> bool:
-        if not isinstance(other, AccessLevel):
-            other = AccessLevel(other)
-        return _accesslevel_order[self.value] <= _accesslevel_order[other.value]
-
-    def __eq__(self, other: object) -> bool:
-        if not isinstance(other, AccessLevel):
-            other = AccessLevel(other)
-        return _accesslevel_order[self.value] == _accesslevel_order[other.value]
-
-    def __str__(self) -> str:
-        return self.value
