@@ -5,15 +5,16 @@ import xml.etree.ElementTree as ET
 from dataclasses import dataclass
 from glob import glob
 from os import PathLike
-from typing import Optional, Union, List, cast, Literal
+from typing import List, Literal, Optional, Sequence, Union, cast
 
 import numpy as np
+import numpy.typing as npt
 import pandas as pd
 
 _UPPERS = "ABCDEFGHIJKLMNOP"
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, order=True, eq=True)
 class FilterSet:
     """Representation of a filter set, potentially including the "quant"
     parameter used by HACFILT in SCPI protocols."""
@@ -23,10 +24,13 @@ class FilterSet:
     quant: bool = True
 
     @classmethod
-    def fromstring(cls, string: str | FilterSet) -> FilterSet:
+    def fromstring(cls, string: str | FilterSet | Sequence) -> FilterSet:
         if isinstance(string, FilterSet):
             return string
         # fixme: do validation
+        if not isinstance(string, str):
+            string = ",".join(string)
+
         if string.startswith("x"):
             return cls(int(string[1]), int(string[4]))
         elif string.startswith("M"):
@@ -66,9 +70,9 @@ class FilterDataReading:
     timestamp: float | None
     exposure: int
     filter_set: FilterSet
-    well_fluorescence: np.ndarray
-    temperatures: np.ndarray
-    set_temperatures: np.ndarray | None
+    well_fluorescence: npt.NDArray[np.float64]
+    temperatures: npt.NDArray[np.float64]
+    set_temperatures: npt.NDArray[np.float64] | None
 
     def __repr__(self):
         return (
@@ -77,6 +81,15 @@ class FilterDataReading:
             f"timestamp={self.timestamp}, ...)"
         )
 
+    @classmethod
+    def from_file(
+        cls, path: str | PathLike[str], sds_dir: str | PathLike[str] | None
+    ) -> FilterDataReading:
+        p = ET.parse(path).find(".//PlateData")
+        if p is None:
+            raise ValueError(f"File {path} is not a valid filter data file.")
+        return cls(p, sds_dir=sds_dir)
+
     def __init__(
         self,
         pde: ET.Element,
@@ -94,7 +107,7 @@ class FilterDataReading:
         }
 
         self.temperatures = np.array(
-            [float(x) for x in attribs["temperature"].split(",")]
+            [float(x) for x in attribs["temperature"].split(",")], dtype=np.float64
         )
 
         self.stage = int(attribs["stage"])
@@ -292,5 +305,5 @@ def df_from_readings(
             ]
             + [("exposure", "exposure")]
         ),
-        axis="columns",
+        axis="columns",  # type: ignore
     )
